@@ -1,4 +1,4 @@
-from typing import Any, Dict
+from typing import Any, Dict, Optional
 import attr
 import logging
 
@@ -53,3 +53,11 @@ class RollbackSpec(object):
 
     def to_dict(self) -> Dict[str, Any]:
         return attr.asdict(self)
+
+
+@attr.s(auto_attribs=True)
+class UploadOptions:
+    cache_maxage: Optional[int] = None
+
+    def to_dict(self) -> Dict[str, Any]:
+        return attr.asdict(self)
